/*
 * Raima Database Manager
 *
 * Copyright (C) 2016 Raims Inc.,  All rights reserved.
 *
 * Use of this software, whether in source code format, or in executable,
 * binary object code form, is governed by the Raima LICENSE which
 * is fully described in the LICENSE.TXT file, included within this
 * distribution of files.
 */

/** \file pspplatcpu.h
 *  \brief Header for the Platform Support Package - Dependent settings for each
 * CPU for each OS
 */

#if !defined(PSPPLATCPU_H_INCLUDED_)
#define PSPPLATCPU_H_INCLUDED_

#include "pspplatdetect.h"

#if defined(RDM_DOXYGEN)
/** Defined for 32-bit systems */
#define RDM_32BIT
#undef RDM_32BIT
/** Defined for 64-bit systems */
#define RDM_64BIT
#undef RDM_64BIT

/** Defined if byte order of little endian */
#define RDM_LITTLEENDIAN
#undef RDM_LITTLEENDIAN
/** Defined if byte order of big endian */
#define RDM_BIGENDIAN
#undef RDM_BIGENDIAN

/** Defined if alignement of 4 bytes is required */
#define RDM_ALIGN4
#undef RDM_ALIGN4
/** Defined if alignement of 4 bytes is required */
#define RDM_ALIGN8
#undef RDM_ALIGN8

/** Careful when copying unaligned date (may be defined on some systems) */
#define RDM_MUSTALIGN
#undef RDM_MUSTALIGN

/** Defined for Android: An OS from Google LLC */
#define RDM_ANDROID
#undef RDM_ANDROID
/** Defined for FreeRTOS */
#define RDM_FREE_RTOS
#undef RDM_FREE_RTOS
/** Defined for INTEGRIRTY: An Green Hills Software Inc */
#define RDM_INTEGRITY
#undef RDM_INTEGRITY
/** Defined for IPhone: An OS from Apple Inc. */
#define RDM_IPHONE
#undef RDM_IPHONE
/** Defined for Linux: An OS developed by the community trademarked by The Linux Mark Institute */
#define RDM_LINUX
#undef RDM_LINUX
/** Defined for QNX Neutrino: An OS from BlackBerry Ltd */
#define RDM_NEUTRINO
#undef RDM_NEUTRINO
/** Defined if no support for any OS. Reentrant without use of any OS calls */
#define RDM_NO_OS
#undef RDM_NO_OS
/** Defined for OS-X: An OS from Apple Inc. */
#define RDM_OSX
#undef RDM_OSX
/** Defined for Solaris: An OS from Oracle Corporation */
#define RDM_SOLARIS
#undef RDM_SOLARIS
/** Defined for Unix, Unix like, or Posix systems */
#define RDM_UNIX
#undef RDM_UNIX
/** Defined for VxWorks: An OS from Wind River Systems, Inc. */
#define RDM_VXWORKS
#undef RDM_VXWORKS
/** Defined for VxWorks RTP: An OS from Wind River Systems, Inc. */
#define RDM_VXWORKS_RTP
#undef RDM_VXWORKS_RTP
/** Defined for Windows: An OS from Microsoft Corporation */
#define RDM_WINDOWS
#undef RDM_WINDOWS

/* In this section we set:
   RDM_<OS>
   RDM_32BIT or RDM_64BIT
   RDM_LITTLEENDIAN or RDM_BIGENDIAN
   RDM_ALIGN4 or RDM_ALIGN8
   RDM_MUSTALIGN where needed
*/

#elif defined(RDM_NO_OS_32)
#define RDM_NO_OS
#define RDM_LITTLEENDIAN
#define RDM_32BIT
#define RDM_ALIGN4

#elif defined(RDM_NO_OS_64)
#define RDM_NO_OS
#define RDM_LITTLEENDIAN
#define RDM_64BIT
#define RDM_ALIGN8

#elif defined(RDM_FREE_RTOS_32)
#define RDM_FREE_RTOS
#define RDM_LITTLEENDIAN
#define RDM_32BIT
#define RDM_ALIGN4

#elif defined(RDM_FREE_RTOS_64)
#define RDM_FREE_RTOS
#define RDM_LITTLEENDIAN
#define RDM_64BIT
#define RDM_ALIGN8

#elif defined(RDM_LINUX_X86)
#define RDM_LINUX
#define RDM_32BIT
#define RDM_LITTLEENDIAN
#define RDM_ALIGN4

#elif defined(RDM_LINUX_X64)
#define RDM_LINUX
#define RDM_64BIT
#define RDM_LITTLEENDIAN
#define RDM_ALIGN8

#elif defined(RDM_LINUX_ITANIUM_64)
#define RDM_LINUX
#define RDM_64BIT
#define RDM_LITTLEENDIAN
#define RDM_ALIGN8

#elif defined(RDM_LINUX_ARM)
#define RDM_LINUX
#define RDM_32BIT
#define RDM_LITTLEENDIAN
#define RDM_ALIGN4
#define RDM_MUSTALIGN

#elif defined(RDM_LINUX_AARCH64)
#define RDM_LINUX
#define RDM_64BIT
#define RDM_LITTLEENDIAN
#define RDM_ALIGN8
#define RDM_MUSTALIGN

#elif defined(RDM_LINUX_POWERPC)
#define RDM_LINUX
#define RDM_32BIT
#define RDM_BIGENDIAN
#define RDM_ALIGN4
#define RDM_MUSTALIGN

#elif defined(RDM_NEUTRINO_X86)
#define RDM_NEUTRINO
#define RDM_32BIT
#define RDM_LITTLEENDIAN
#define RDM_ALIGN4

#elif defined(RDM_NEUTRINO_X86_64)
#define RDM_NEUTRINO
#define RDM_64BIT
#define RDM_LITTLEENDIAN
#define RDM_ALIGN8

#elif defined(RDM_NEUTRINO_ARM)
#define RDM_NEUTRINO
#define RDM_32BIT
#define RDM_LITTLEENDIAN
#define RDM_ALIGN4
#define RDM_MUSTALIGN

#elif defined(RDM_NEUTRINO_ARM64)
#define RDM_NEUTRINO
#define RDM_64BIT
#define RDM_LITTLEENDIAN
#define RDM_ALIGN8
#define RDM_MUSTALIGN

#elif defined(RDM_NEUTRINO_PPC)
#define RDM_NEUTRINO
#define RDM_32BIT
#define RDM_BIGENDIAN
#define RDM_ALIGN4
#define RDM_MUSTALIGN

#elif defined(RDM_IPHONE_ARM)
#define RDM_IPHONE
#define RDM_32BIT
#define RDM_LITTLEENDIAN
#define RDM_ALIGN4
#define RDM_MUSTALIGN

#elif defined(RDM_OSX_X86)
#define RDM_OSX
#define RDM_32BIT
#define RDM_LITTLEENDIAN
#define RDM_ALIGN4

#elif defined(RDM_OSX_X64)
#define RDM_OSX
#define RDM_64BIT
#define RDM_LITTLEENDIAN
#define RDM_ALIGN8

#elif defined(RDM_SOLARIS_X86)
#define RDM_SOLARIS
#define RDM_32BIT
#define RDM_LITTLEENDIAN
#define RDM_ALIGN4

#elif defined(RDM_SOLARIS_X64)
#define RDM_SOLARIS
#define RDM_64BIT
#define RDM_LITTLEENDIAN
#define RDM_ALIGN4

#elif defined(RDM_SOLARIS_SPARC_32)
#define RDM_SOLARIS
#define RDM_32BIT
#define RDM_BIGENDIAN
#define RDM_ALIGN8
#define RDM_MUSTALIGN

#elif defined(RDM_SOLARIS_SPARC_64)
#define RDM_SOLARIS
#define RDM_64BIT
#define RDM_BIGENDIAN
#define RDM_ALIGN8
#define RDM_MUSTALIGN

#elif defined(RDM_WINDOWS_X86)
#define RDM_WINDOWS
#define RDM_32BIT
#define RDM_LITTLEENDIAN
#define RDM_ALIGN8

#elif defined(RDM_WINDOWS_X64)
#define RDM_WINDOWS
#define RDM_64BIT
#define RDM_LITTLEENDIAN
#define RDM_ALIGN8

#elif defined(RDM_VXWORKS_RTP_X86)
#define RDM_VXWORKS_RTP
#define RDM_32BIT
#define RDM_LITTLEENDIAN
#define RDM_ALIGN4

#elif defined(RDM_VXWORKS_RTP_POWERPC)
#define RDM_VXWORKS_RTP
#define RDM_32BIT
#define RDM_BIGENDIAN
#define RDM_ALIGN4

#elif defined(RDM_VXWORKS_RTP_ARM)
#define RDM_VXWORKS_RTP
#define RDM_32BIT
#define RDM_LITTLEENDIAN
#define RDM_ALIGN4

#elif defined(RDM_VXWORKS_X86)
#define RDM_VXWORKS
#define RDM_32BIT
#define RDM_LITTLEENDIAN
#define RDM_ALIGN4

#elif defined(VXWORKS_X64)
#define RDM_VXWORKS
#define RDM_64BIT
#define RDM_LITTLEENDIAN
#define RDM_ALIGN4

#elif defined(RDM_VXWORKS_POWERPC)
#define RDM_VXWORKS
#define RDM_32BIT
#define RDM_BIGENDIAN
#define RDM_ALIGN4

#elif defined(VXWORKS_MIPS)
#define RDM_VXWORKS
#define RDM_32BIT
#define RDM_BIGENDIAN
#define RDM_ALIGN4

#elif defined(RDM_VXWORKS_SH4)
#define RDM_VXWORKS
#define RDM_32BIT
#define RDM_LITTLEENDIAN
#define RDM_ALIGN4
#define RDM_MUSTALIGN

#elif defined(RDM_VXWORKS_ARM)
#define RDM_VXWORKS
#define RDM_32BIT
#define RDM_LITTLEENDIAN
#define RDM_ALIGN4

#elif defined(RDM_INTEGRITY_X86)
#define RDM_INTEGRITY
#define RDM_32BIT
#define RDM_LITTLEENDIAN
#define RDM_ALIGN4

#elif defined(RDM_INTEGRITY_ARM)
#define RDM_INTEGRITY
#define RDM_32BIT
#define RDM_LITTLEENDIAN
#define RDM_ALIGN4

#elif defined(RDM_INTEGRITY_POWERPC)
#define RDM_INTEGRITY
#define RDM_32BIT
#define RDM_BIGENDIAN
#define RDM_MUSTALIGN
#define RDM_ALIGN4

#elif defined(RDM_ANDROID_ARM)
#define RDM_ANDROID
#define RDM_32BIT
#define RDM_LITTLEENDIAN
#define RDM_ALIGN4
#define RDM_MUSTALIGN

#else
#error No CPU specific section found
#endif

#endif /* PSPPLATCPU_H_INCLUDED_ */
